@@ -68,6 +68,8 @@ struct _RepoEditInfo {
     GtkWidget *chk_double_size;
     GtkWidget *chk_nextable;
     GtkWidget *btn_browse;
+    GtkWidget *num_min_zoom;
+    GtkWidget *num_max_zoom;
     BrowseInfo browse_info;
 };
 
@@ -131,10 +133,10 @@ mapdb_exists(RepoData *repo, gint zoom, gint tilex, gint tiley)
 #else
     {
         datum d;
-        gint key[] = {
-            GLONG_TO_BE(zoom),
-            GLONG_TO_BE(tilex),
-            GLONG_TO_BE(tiley)
+        gint32 key[] = {
+            GINT32_TO_BE(zoom),
+            GINT32_TO_BE(tilex),
+            GINT32_TO_BE(tiley)
         };
         d.dptr = (gchar*)&key;
         d.dsize = sizeof(key);
@@ -228,10 +230,10 @@ mapdb_get(RepoData *repo, gint zoom, gint tilex, gint tiley)
 #else
     {
         datum d;
-        gint key[] = {
-            GLONG_TO_BE(zoom),
-            GLONG_TO_BE(tilex),
-            GLONG_TO_BE(tiley)
+        gint32 key[] = {
+            GINT32_TO_BE(zoom),
+            GINT32_TO_BE(tilex),
+            GINT32_TO_BE(tiley)
         };
         d.dptr = (gchar*)&key;
         d.dsize = sizeof(key);
@@ -411,10 +413,10 @@ mapdb_update(gboolean exists, RepoData *repo,
 #else
     {
         datum dkey, dcon;
-        gint key[] = {
-            GLONG_TO_BE(zoom),
-            GLONG_TO_BE(tilex),
-            GLONG_TO_BE(tiley)
+        gint32 key[] = {
+            GINT32_TO_BE(zoom),
+            GINT32_TO_BE(tilex),
+            GINT32_TO_BE(tiley)
         };
         dkey.dptr = (gchar*)&key;
         dkey.dsize = sizeof(key);
@@ -478,10 +480,10 @@ mapdb_delete(RepoData *repo, gint zoom, gint tilex, gint tiley)
 #else
     {
         datum d;
-        gint key[] = {
-            GLONG_TO_BE(zoom),
-            GLONG_TO_BE(tilex),
-            GLONG_TO_BE(tiley)
+        gint32 key[] = {
+            GINT32_TO_BE(zoom),
+            GINT32_TO_BE(tilex),
+            GINT32_TO_BE(tiley)
         };
         d.dptr = (gchar*)&key;
         d.dsize = sizeof(key);
@@ -743,7 +745,7 @@ map_convert_wms_to_wms(gint tilex, gint tiley, gint zoomlevel, gchar* uri)
     gchar cmd[BUFFER_SIZE], srs[BUFFER_SIZE];
     gchar *ret = NULL;
     FILE* in;
-    gfloat lon1, lat1, lon2, lat2;
+    gdouble lon1, lat1, lon2, lat2;
 
     gchar *widthstr   = strcasestr(uri,"WIDTH=");
     gchar *heightstr  = strcasestr(uri,"HEIGHT=");
@@ -788,7 +790,8 @@ map_convert_wms_to_wms(gint tilex, gint tiley, gint zoomlevel, gchar* uri)
                 WEXITSTATUS(system_retcode));
     else if(!(in = g_fopen("/tmp/tmpcs2cs","r")))
         g_printerr("Cannot open results of conversion\n");
-    else if(5 != fscanf(in,"%f %f %s %f %f", &lon1, &lat1, cmd, &lon2, &lat2))
+    else if(5 != fscanf(in,"%lf %lf %s %lf %lf",
+                &lon1, &lat1, cmd, &lon2, &lat2))
     {
         g_printerr("Wrong conversion\n");
         fclose(in);
@@ -1392,20 +1395,20 @@ repoman_dialog_add_repo(RepoManInfo *rmi, gchar *name)
     /* Map download URI. */
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_label_new(_("URL Format")),
-            0, 1, 0, 1, GTK_FILL, 0, 2, 4);
+            0, 1, 0, 1, GTK_FILL, 0, 2, 0);
     gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
     gtk_table_attach(GTK_TABLE(table),
             rei->txt_url = gtk_entry_new(),
-            1, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 2, 4);
+            1, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 2, 0);
 
     /* Map Directory. */
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_label_new(_("Cache DB")),
-            0, 1, 1, 2, GTK_FILL, 0, 2, 4);
+            0, 1, 1, 2, GTK_FILL, 0, 2, 0);
     gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
     gtk_table_attach(GTK_TABLE(table),
             hbox = gtk_hbox_new(FALSE, 4),
-            1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 2, 4);
+            1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 2, 0);
     gtk_box_pack_start(GTK_BOX(hbox),
             rei->txt_db_filename = gtk_entry_new(),
             TRUE, TRUE, 0);
@@ -1433,11 +1436,11 @@ repoman_dialog_add_repo(RepoManInfo *rmi, gchar *name)
     /* Download Zoom Steps. */
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_label_new(_("Download Zoom Steps")),
-            0, 1, 0, 1, GTK_FILL, 0, 2, 4);
+            0, 1, 0, 1, GTK_FILL, 0, 2, 0);
     gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_alignment_new(0.f, 0.5f, 0.f, 0.f),
-            1, 2, 0, 1, GTK_FILL, 0, 2, 4);
+            1, 2, 0, 1, GTK_FILL, 0, 2, 0);
     gtk_container_add(GTK_CONTAINER(label),
             rei->num_dl_zoom_steps = hildon_controlbar_new());
     hildon_controlbar_set_range(
@@ -1449,11 +1452,11 @@ repoman_dialog_add_repo(RepoManInfo *rmi, gchar *name)
     /* Download Zoom Steps. */
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_label_new(_("View Zoom Steps")),
-            0, 1, 1, 2, GTK_FILL, 0, 2, 4);
+            0, 1, 1, 2, GTK_FILL, 0, 2, 0);
     gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_alignment_new(0.f, 0.5f, 0.f, 0.f),
-            1, 2, 1, 2, GTK_FILL, 0, 2, 4);
+            1, 2, 1, 2, GTK_FILL, 0, 2, 0);
     gtk_container_add(GTK_CONTAINER(label),
             rei->num_view_zoom_steps = hildon_controlbar_new());
     hildon_controlbar_set_range(
@@ -1464,13 +1467,13 @@ repoman_dialog_add_repo(RepoManInfo *rmi, gchar *name)
 
     gtk_table_attach(GTK_TABLE(table),
             label = gtk_vseparator_new(),
-            2, 3, 0, 2, GTK_FILL, GTK_FILL, 4, 4);
+            2, 3, 0, 2, GTK_FILL, GTK_FILL, 4, 0);
 
     /* Double-size. */
     gtk_table_attach(GTK_TABLE(table),
             rei->chk_double_size = gtk_check_button_new_with_label(
                 _("Double Pixels")),
-            3, 4, 0, 1, GTK_FILL, GTK_FILL, 0, 4);
+            3, 4, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
     gtk_toggle_button_set_active(
             GTK_TOGGLE_BUTTON(rei->chk_double_size), FALSE);
 
@@ -1478,10 +1481,40 @@ repoman_dialog_add_repo(RepoManInfo *rmi, gchar *name)
     gtk_table_attach(GTK_TABLE(table),
             rei->chk_nextable = gtk_check_button_new_with_label(
                 _("Next-able")),
-            3, 4, 1, 2, GTK_FILL, GTK_FILL, 0, 4);
+            3, 4, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
     gtk_toggle_button_set_active(
             GTK_TOGGLE_BUTTON(rei->chk_nextable), TRUE);
 
+    /* Downloadable Zoom Levels. */
+    gtk_table_attach(GTK_TABLE(table),
+            label = gtk_label_new(_("Downloadable Zooms:")),
+            0, 1, 2, 3, GTK_FILL, 0, 2, 0);
+    gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
+    gtk_table_attach(GTK_TABLE(table),
+            label = gtk_alignment_new(0.f, 0.5f, 0.f, 0.f),
+            1, 4, 2, 3, GTK_FILL, 0, 2, 0);
+    gtk_container_add(GTK_CONTAINER(label),
+            hbox = gtk_hbox_new(FALSE, 4));
+    gtk_box_pack_start(GTK_BOX(hbox),
+            label = gtk_label_new(_("Min.")),
+            TRUE, TRUE, 0);
+    gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
+    gtk_box_pack_start(GTK_BOX(hbox),
+            rei->num_min_zoom = hildon_number_editor_new(MIN_ZOOM, MAX_ZOOM),
+            FALSE, FALSE, 0);
+    hildon_number_editor_set_value(HILDON_NUMBER_EDITOR(rei->num_min_zoom), 4);
+    gtk_box_pack_start(GTK_BOX(hbox),
+            label = gtk_label_new(""),
+            TRUE, TRUE, 4);
+    gtk_box_pack_start(GTK_BOX(hbox),
+            label = gtk_label_new(_("Max.")),
+            TRUE, TRUE, 0);
+    gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
+    gtk_box_pack_start(GTK_BOX(hbox),
+            rei->num_max_zoom = hildon_number_editor_new(MIN_ZOOM, MAX_ZOOM),
+            FALSE, FALSE, 0);
+    hildon_number_editor_set_value(HILDON_NUMBER_EDITOR(rei->num_max_zoom),20);
+
     rmi->repo_edits = g_list_append(rmi->repo_edits, rei);
 
     /* Connect signals. */
@@ -1639,6 +1672,12 @@ repoman_download(GtkWidget *widget, RepoManInfo *rmi)
                 gtk_toggle_button_set_active(
                         GTK_TOGGLE_BUTTON(rei->chk_nextable),
                         rd->nextable);
+                hildon_number_editor_set_value(
+                        HILDON_NUMBER_EDITOR(rei->num_min_zoom),
+                        rd->min_zoom);
+                hildon_number_editor_set_value(
+                        HILDON_NUMBER_EDITOR(rei->num_max_zoom),
+                        rd->max_zoom);
             }
             g_free(bytes);
         }
@@ -1755,6 +1794,12 @@ repoman_dialog()
         gtk_toggle_button_set_active(
                 GTK_TOGGLE_BUTTON(rei->chk_nextable),
                 rd->nextable);
+        hildon_number_editor_set_value(
+                HILDON_NUMBER_EDITOR(rei->num_min_zoom),
+                rd->min_zoom);
+        hildon_number_editor_set_value(
+                HILDON_NUMBER_EDITOR(rei->num_max_zoom),
+                rd->max_zoom);
         if(rd == _curr_repo)
             curr_repo_index = i;
     }
@@ -1767,10 +1812,33 @@ repoman_dialog()
     while(GTK_RESPONSE_ACCEPT == gtk_dialog_run(GTK_DIALOG(dialog)))
     {
         /* Iterate through repos and verify each. */
+        gboolean verified = TRUE;
         gint i;
         GList *curr;
         gchar *old_curr_repo_name = _curr_repo->name;
 
+        for(i = 0, curr = rmi.repo_edits; curr; curr = curr->next, i++)
+        {
+            /* Check the ranges for the min and max zoom levels. */
+            RepoEditInfo *rei = curr->data;
+            if(hildon_number_editor_get_value(
+                        HILDON_NUMBER_EDITOR(rei->num_max_zoom))
+                 < hildon_number_editor_get_value(
+                        HILDON_NUMBER_EDITOR(rei->num_min_zoom)))
+            {
+                verified = FALSE;
+                break;
+            }
+        }
+        if(!verified)
+        {
+            gtk_combo_box_set_active(GTK_COMBO_BOX(rmi.cmb_repos), i);
+            popup_error(dialog,
+                    _("Minimum Downloadable Zoom must be less than "
+                        "Maximum Downloadable Zoom."));
+            continue;
+        }
+
         /* We're good to replace.  Remove old _repo_list menu items. */
         menu_maps_remove_repos();
         /* But keep the repo list in memory, in case downloads are using it. */
@@ -1796,6 +1864,10 @@ repoman_dialog()
                     GTK_TOGGLE_BUTTON(rei->chk_double_size));
             rd->nextable = gtk_toggle_button_get_active(
                     GTK_TOGGLE_BUTTON(rei->chk_nextable));
+            rd->min_zoom = hildon_number_editor_get_value(
+                    HILDON_NUMBER_EDITOR(rei->num_min_zoom));
+            rd->max_zoom = hildon_number_editor_get_value(
+                    HILDON_NUMBER_EDITOR(rei->num_max_zoom));
             set_repo_type(rd);
 
             _repo_list = g_list_append(_repo_list, rd);
@@ -1826,8 +1898,8 @@ repoman_dialog()
 }
 
 static gboolean
-mapman_by_area(gfloat start_lat, gfloat start_lon,
-        gfloat end_lat, gfloat end_lon, MapmanInfo *mapman_info,
+mapman_by_area(gdouble start_lat, gdouble start_lon,
+        gdouble end_lat, gdouble end_lon, MapmanInfo *mapman_info,
         MapUpdateType update_type,
         gint download_batch_id)
 {
@@ -2116,7 +2188,7 @@ mapman_dialog()
     static GtkWidget *lbl_center_lon = NULL;
     static MapmanInfo mapman_info;
     gchar buffer[80];
-    gfloat lat, lon;
+    gdouble lat, lon;
     gint z;
     printf("%s()\n", __PRETTY_FUNCTION__);
 
